@@ -1,4 +1,5 @@
 import functools
+import logging
 import operator
 from datetime import timedelta
 from typing import TYPE_CHECKING
@@ -34,6 +35,7 @@ if TYPE_CHECKING:
     from ephios.core.models import UserProfile
     from ephios.core.signup.methods import BaseSignupMethod, SignupStats
     from ephios.core.signup.participants import AbstractParticipant
+logger = logging.getLogger(__name__)
 
 
 class ActiveManager(Manager):
@@ -174,6 +176,11 @@ class DatetimeDisplayMixin:
         return f"{self.get_date_display()}, {self.get_time_display()}"
 
 
+# https://github.com/django-polymorphic/django-polymorphic/issues/229#issuecomment-398434412
+def NON_POLYMORPHIC_CASCADE(collector, field, sub_objs, using):
+    return models.CASCADE(collector, field, sub_objs.non_polymorphic(), using)
+
+
 class AbstractParticipation(DatetimeDisplayMixin, PolymorphicModel):
     class States(models.IntegerChoices):
         REQUESTED = 0, _("requested")
@@ -187,7 +194,10 @@ class AbstractParticipation(DatetimeDisplayMixin, PolymorphicModel):
             return dict(zip(cls.values, cls.labels))
 
     shift = ForeignKey(
-        "Shift", on_delete=models.CASCADE, verbose_name=_("shift"), related_name="participations"
+        "Shift",
+        on_delete=NON_POLYMORPHIC_CASCADE,
+        verbose_name=_("shift"),
+        related_name="participations",
     )
     state = IntegerField(_("state"), choices=States.choices, default=States.GETTING_DISPATCHED)
     data = models.JSONField(default=dict, verbose_name=_("Signup data"))
@@ -274,7 +284,10 @@ class Shift(DatetimeDisplayMixin, Model):
         try:
             return signup_method_from_slug(self.signup_method_slug, self, event=event)
         except ValueError:
-            return None
+            logger.warning(f"signup method {self.signup_method_slug} was not found")
+            from ephios.core.signup.fallback import FallbackSignupMethod
+
+            return FallbackSignupMethod(self, event=event)
 
     def get_participants(self, with_state_in=frozenset({AbstractParticipation.States.CONFIRMED})):
         for participation in self.participations.filter(state__in=with_state_in):
