@@ -79,9 +79,15 @@ class UserProfileManager(BaseUserManager):
         return user
 
 
+class VisibleUserProfileManager(BaseUserManager):
+    def get_queryset(self):
+        return super().get_queryset().filter(is_visible=True)
+
+
 class UserProfile(guardian.mixins.GuardianUserMixin, PermissionsMixin, AbstractBaseUser):
     email = EmailField(_("email address"), unique=True)
     is_active = BooleanField(default=True, verbose_name=_("Active"))
+    is_visible = BooleanField(default=True, verbose_name=_("Visible"))
     is_staff = BooleanField(default=False, verbose_name=_("Staff user"))
     first_name = CharField(_("first name"), max_length=254)
     last_name = CharField(_("last name"), max_length=254)
@@ -96,12 +102,15 @@ class UserProfile(guardian.mixins.GuardianUserMixin, PermissionsMixin, AbstractB
         "date_of_birth",
     ]
 
-    objects = UserProfileManager()
+    objects = VisibleUserProfileManager()
+    all_objects = UserProfileManager()
 
     class Meta:
         verbose_name = _("user profile")
         verbose_name_plural = _("user profiles")
         db_table = "userprofile"
+        base_manager_name = "all_objects"
+        default_manager_name = "all_objects"
 
     def get_full_name(self):
         return self.first_name + " " + self.last_name
@@ -122,7 +131,7 @@ class UserProfile(guardian.mixins.GuardianUserMixin, PermissionsMixin, AbstractB
         return self.age < 18
 
     def as_participant(self):
-        from ephios.core.signup import LocalUserParticipant
+        from ephios.core.signup.participants import LocalUserParticipant
 
         return LocalUserParticipant(
             first_name=self.first_name,
@@ -141,25 +150,17 @@ class UserProfile(guardian.mixins.GuardianUserMixin, PermissionsMixin, AbstractB
             expires=Max(F("grants__expires"), filter=Q(grants__user=self)),
         )
 
-    def get_shifts(self, with_participation_state_in):
-        from ephios.core.models import Shift
-
-        shift_ids = self.localparticipation_set.filter(
-            state__in=with_participation_state_in
-        ).values_list("shift", flat=True)
-        return Shift.objects.filter(pk__in=shift_ids).select_related("event")
-
     def get_workhour_items(self):
         from ephios.core.models import AbstractParticipation
 
         participations = (
-            self.localparticipation_set.filter(state=AbstractParticipation.States.CONFIRMED)
+            self.participations.filter(state=AbstractParticipation.States.CONFIRMED)
             .annotate(
                 duration=ExpressionWrapper(
-                    (F("shift__end_time") - F("shift__start_time")),
+                    (F("end_time") - F("start_time")),
                     output_field=models.DurationField(),
                 ),
-                date=ExpressionWrapper(TruncDate(F("shift__start_time")), output_field=DateField()),
+                date=ExpressionWrapper(TruncDate(F("start_time")), output_field=DateField()),
                 reason=F("shift__event__title"),
             )
             .values("duration", "date", "reason")
@@ -448,6 +449,7 @@ class Notification(Model):
     data = models.JSONField(
         blank=True, default=dict, encoder=CustomJSONEncoder, decoder=CustomJSONDecoder
     )
+    created_at = models.DateTimeField(auto_now_add=True)
 
     @functools.cached_property
     def notification_type(self):
