@@ -549,17 +549,16 @@ class BaseSignupMethod:
                     errors.append(error)
         return errors
 
-    @functools.lru_cache()
+    @functools.lru_cache(maxsize=64)
     def get_signup_errors(self, participant) -> List[ParticipationError]:
         """Return a list of ParticipationErrors that describe reasons for not being able to sign up."""
         return self._run_checkers(participant, self._signup_checkers)
 
-    @functools.lru_cache()
+    @functools.lru_cache(maxsize=64)
     def get_decline_errors(self, participant):
         """Return a list of ParticipationErrors that describe reasons for not being able to decline."""
         return self._run_checkers(participant, self._decline_checkers)
 
-    @functools.lru_cache()
     def get_participant_errors(self, participant) -> List[ParticipationError]:
         """
         Return errors for whether the participant fulfills the requirements set by the signup methods for participation.
